@@ -1,4 +1,4 @@
-#ident "@(#)cnd.c	$Id: cnd.c,v 4.14 1999/01/12 23:08:15 gert Exp $ Copyright (c) 1993 Gert Doering/Chris Lewis"
+#ident "@(#)cnd.c	$Id: cnd.c,v 4.22 2001/10/21 15:02:28 gert Exp $ Copyright (c) 1993 Gert Doering/Chris Lewis"
 
 #include <stdio.h>
 #include <string.h>
@@ -46,6 +46,9 @@ struct cndtable cndtable[] =
     {"REASON FOR NO CALLER NUMBER: ",	&CallerId},
     {"REASON FOR NO CALLER NAME: ",	&CallName},
 
+    /* isdn4linux (2.4.10 or patched) - Jan Oberlaender, mindriot@gmx.net */
+    {"CALLED NUMBER: ",		&CalledNr},
+
     /* for the ZyXEL 2864(D)I: "FM:xxx TO:yyy" */
     {"FM:",			&CallerId},
 
@@ -66,12 +69,31 @@ struct cndtable cndtable[] =
     {"MESG = ",			&CallMsg1},
     {"MESG = ",			&CallMsg2},
 
+    /* some Rockwell chips intro the Caller ID as follows */
+    /* (contributed by Edmund Bacon, ebacon@onesystem.com) */
+    {"DDN_NMBR= ",		&CallerId},
+
+    /* The Digi DataFire RAS reports this different again... */
+    /* (reported by Akiko Takahashi <takahashi@sdcinc.co.jp>) */
+    /* also for the Zoom 2949L, K C Yuen <ykc@kernelhk.com> */
+    /* also used by ELSA MicroLink Office <gert@greenie.muc.de> */
+    {"DATE=",			&CallDate},
+    {"TIME=",			&CallTime},
+    {"NMBR=",			&CallerId},
+    {"NAME=",			&CallName},
+
     /* yet another incompatible modem... */
     {"CALLER'S NUMBER: ",	&CallerId},
 
     /* Kortex Adaptix 56000 (Quercia Michel, quercia@cal.enst.fr) */
     {"NBR=",			&CallerId},
 
+    /* Russian USR Courier V.everything hackware, Alexey Promokhov */
+    {"CallerID: ",		&CallerId},
+
+    /* Swedish Telia/ZyXEL Omni 52k - Torulf Lundgren, torulf@upsys.se */
+    {"Diverting number:",       &CallerId},
+
     {NULL}
 };
     
