@@ -1,4 +1,4 @@
-#ident "$Id: faxlib.c,v 4.44 1999/06/15 20:53:53 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxlib.c,v 4.51 2001/10/01 18:47:18 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxlib.c
  *
@@ -613,6 +613,12 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_type=Mt_data;				/* has no fax mode */
 	    mis = mdm_get_idstring( "ATI1", 1, fd );
 	    break;
+	  case 1500:
+	  case 1501:
+	    lprintf( L_MESG, "ZyXEL Omni 56K (Plus) detected" );
+	    modem_type=Mt_class2_0;
+	    mis = mdm_get_idstring( "ATI1", 2, fd );
+	    break;
 	  case 1444:
 	    lprintf( L_MESG, "USR Courier/Sportster v32bis detected (assuming non-fax capable)" );
 	    modem_type=Mt_data;
@@ -699,6 +705,11 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_type=Mt_class2_0;
 	    mis = mdm_get_idstring( "ATI3", 1, fd );
 	    break;
+	  case 645:	/* ATI6/ATI3 for model/firmware info */
+	    lprintf( L_MESG, "ELSA MicroLink Internet II detected" );
+	    modem_type=Mt_class2_0;
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	    break;
 	  case 282:	/* ATI6/ATI3 for model/firmware info */
 	    lprintf( L_MESG, "ELSA MicroLink 28.8/56K series detected" );
 	    modem_type=Mt_class2_0;
@@ -742,6 +753,11 @@ int mdm_identify _P1( (fd), int fd )
 	  case 336:				/* one report only */
 	    lprintf( L_MESG, "could be a CompuTime RalleyCom 336" );
 	    break;
+	  case 242:				/* one report only */
+	    lprintf( L_MESG, "could be a Tornado III FM-144VBIS" );
+	    modem_type=Mt_class2;
+	    modem_quirks |= MQ_NO_XON;
+	    break;
 	  default:
 	    lprintf( L_MESG, "unknown numerical modem id %d", mid );
 	    break;
@@ -752,10 +768,14 @@ int mdm_identify _P1( (fd), int fd )
 	lprintf( L_MESG, "non-numeric ID string: '%s'", l );
 
 	/* "Elink 310 Version 1.25" */
+	/* "Elink 34-3 P1 Version 1.64" */
 	if ( strncmp( l, "Elink", 5 ) == 0 )
 	{
 	    lprintf( L_MESG, "Elink detected" );
-	    modem_type=Mt_data;
+	    if ( strncmp( l+6, "34-3" , 4 ) == 0 )
+		modem_type=Mt_class2;
+	    else
+		modem_type=Mt_data;
 	}
 	else if ( strncmp( l, "Linux ISDN", 10 ) == 0 )
 	{
@@ -791,6 +811,20 @@ int mdm_identify _P1( (fd), int fd )
 	    lprintf( L_MESG, "Multitech MT5600ZDXV detected" );
 	    modem_type=Mt_class2;
 	}
+	/* and yet another one :-( - Nokia, sigh */
+	else if ( strncmp( l, "Nokia ", 6 ) == 0 )
+	{
+	    lprintf( L_MESG, "Nokia GSM telephone detected" );
+	    modem_type=Mt_class2_0;
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	}
+	/* and yet another one - will they never end? Xavier Roche */
+	else if ( strncmp( l, "LT V.90", 7 ) == 0 )
+	{
+	    lprintf( L_MESG, "Multitech MT5634Z internal detected" );
+	    modem_type=Mt_class2;
+	    modem_quirks |= MQ_NEED2;
+	}
     }
 
     if ( mis != NULL ) 
