@@ -1,4 +1,4 @@
-#ident "$Id: login.c,v 4.10 1999/05/24 13:35:31 gert Exp $ Copyright (C) 1993 Gert Doering"
+#ident "$Id: login.c,v 4.12 2001/03/13 20:32:40 gert Exp $ Copyright (C) 1993 Gert Doering"
 
 
 /* login.c
@@ -299,6 +299,10 @@ void login_dispatch _P3( (user, is_callback, cfg_file ),
 		{
 		    argv[argc++] = Connect[0]? Connect: "??";
 		}
+		else if ( strcmp( p, "\\Y" ) == 0 )	/* CallerID */
+		{
+		    argv[argc++] = CallerId;
+		}
 		else
 		    argv[argc++] = p;
 		
@@ -365,4 +369,5 @@ void setup_environment _P0(void)
     set_env_var( "CALLER_ID", CallerId );
     set_env_var( "CALLED_ID", CalledNr );
     set_env_var( "CONNECT", Connect );
+    set_env_var( "DEVICE", Device );
 }
