@@ -1,4 +1,4 @@
-#ident "$Id: mgetty.c,v 4.27 1999/06/01 14:52:11 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mgetty.c,v 4.32 2001/09/28 21:09:39 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.c
  *
@@ -64,7 +64,7 @@ chat_action_t	* answer_chat_actions = &ring_chat_actions[1];
 /* prototypes for system functions (that are missing in some 
  * system header files)
  */
-#ifndef __NetBSD__
+#if !defined(__NetBSD__) && !defined(__OpenBSD__)
 time_t		time _PROTO(( long * tloc ));
 #endif
 
@@ -100,7 +100,6 @@ static RETSIGTYPE sig_goodbye _P1 ( (signo), int signo )
     exit(10);
 }
 
-#ifdef MGETTY_PID_FILE
 /* create a file with the process ID of the mgetty currently
  * active on a given device in it.
  */
@@ -109,7 +108,7 @@ static void make_pid_file _P0( void )
 {
     FILE * fp;
 
-    sprintf( pid_file_name, MGETTY_PID_FILE, DevID );
+    sprintf( pid_file_name, "%s/mgetty.pid.%s", VARRUNDIR, DevID );
 
     fp = fopen( pid_file_name, "w" );
     if ( fp == NULL )
@@ -121,7 +120,6 @@ static void make_pid_file _P0( void )
     if ( chmod( pid_file_name, 0644 ) != 0 )
         lprintf( L_ERROR, "can't chmod() pid file" );
 }
-#endif
     
 
 enum mgetty_States
@@ -376,9 +374,7 @@ int main _P2((argc, argv), int argc, char ** argv)
     lprintf( L_MESG, "gettydefs tag used: %s", c_string(gettydefs_tag) );
 #endif
 
-#ifdef MGETTY_PID_FILE
     make_pid_file();
-#endif
 
     lprintf(L_MESG, "check for lockfiles");
 
@@ -757,6 +753,7 @@ Ring_got_action:
 		     ! c_bool(ringback))/* and not "missed" ringback */
 		{
 		    lprintf( L_WARN, "huh? Junk on the line?" );
+		    lprintf( L_WARN, " >>> could be a dial-out program without proper locking - check this!" );
 		    rmlocks();		/* line is free again */
 		    exit(0);		/* let init restart mgetty */
 		}
@@ -829,20 +826,23 @@ Ring_got_action:
 
 #ifdef VOICE
 	    if ( use_voice_mode ) {
+		int rc; 
 		/* Answer in voice mode. The function will return only if it
 		   detects a data call, otherwise it will call exit(). */
+		rc = vgetty_answer(rings, rings_wanted, dist_ring);
 		
 		/* The modem will be in voice mode when voice_answer is
-		   called. If the function returns, the modem is ready
-		   to be connected in DATA mode with ATA. */
-
-		if ( vgetty_answer(rings, rings_wanted, dist_ring) ==
-		 VMA_CONNECT )
-		{
-		/* unexpected "CONNECT" -> jump to reading of login name
+		 * called. If the function returns, the modem is ready
+		 * to be connected in DATA mode with ATA.
+		 *
+		 * Exception: a CONNECT has been seen (-> go to "login:")
+		 *   or a fax connection is established (go to fax receive)
 		 */
-		    mgetty_state = St_get_login; break;
-		};
+
+		if ( rc == VMA_CONNECT )
+		    { mgetty_state = St_get_login; break; }
+		if ( rc == VMA_FCO || rc == VMA_FCON || rc == VMA_FAX )
+		    { mgetty_state = St_incoming_fax; break; }
 	    }
 #endif /* VOICE */
 
@@ -902,7 +902,7 @@ Ring_got_action:
 
 	    lprintf( L_MESG, "start fax receiver..." );
 	    get_ugid( &c.fax_owner, &c.fax_group, &uid, &gid );
-	    faxrec( FAX_SPOOL_IN, c_int(switchbd),
+	    faxrec( c_string(fax_spool_in), c_int(switchbd),
 		    uid, gid, c_int(fax_mode),
 		    c_isset(notify_mail)? c_string(notify_mail): NULL );
 
@@ -950,7 +950,8 @@ Ring_got_action:
     
     /* make utmp and wtmp entry (otherwise login won't work)
      */
-    make_utmp_wtmp( Device, UT_LOGIN, "LOGIN", Connect );
+    make_utmp_wtmp( Device, UT_LOGIN, "LOGIN", 
+		      strcmp( CallerId, "none" ) != 0 ? CallerId: Connect );
 
     /* wait a little bit befor printing login: prompt (to give
      * the other side time to get ready)
@@ -1037,9 +1038,7 @@ Ring_got_action:
 	}
 
 	/* remove PID file (mgetty is due to exec() login) */
-#ifdef MGETTY_PID_FILE
 	(void) unlink( pid_file_name );
-#endif
 
 	/* dreadful hack for Linux, set TERM if desired */
 	if ( c_isset(termtype) )
