@@ -1,4 +1,4 @@
-#ident "$Id: mksed.c,v 4.6 1998/03/30 18:23:30 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mksed.c,v 4.8 2001/01/28 14:54:36 gert Exp $ Copyright (c) Gert Doering"
 
 #include <stdio.h>
 
@@ -16,6 +16,7 @@ int main _P0( void )
     printf( "      -e 's;@FAX_SPOOL@;%s;g'\\\n", FAX_SPOOL );
     printf( "      -e 's;@FAX_SPOOL_IN@;%s;g'\\\n", FAX_SPOOL_IN );
     printf( "      -e 's;@FAX_SPOOL_OUT@;%s;g'\\\n", FAX_SPOOL_OUT );
+    printf( "      -e 's;@VARRUNDIR@;%s;g'\\\n", VARRUNDIR );
     printf( "      -e 's;@FAX_MODEM_TTYS@;%s;g'\\\n", FAX_MODEM_TTYS );
     printf( "      -e 's;@FAX_STATION_ID@;%s;g'\\\n", FAX_STATION_ID );
     printf( "      -e 's;@FAX_LOG@;%s;g'\\\n", FAX_LOG );
@@ -26,13 +27,7 @@ int main _P0( void )
     printf( "      -e 's;@NOLOGIN@;" );
 	printf( NOLOGIN_FILE, "ttyxx" );
         printf( ";g'\\\n" );
-    printf( "      -e 's;@KVG_PID_FILE@;");
-#ifdef MGETTY_PID_FILE
-        printf( MGETTY_PID_FILE, "$TTY" );
-        printf( ";g'\\\n" );
-#else
-        printf( "/etc/mg-pid.$TTY;g'\\\n" );
-#endif
+    printf( "      -e 's;@KVG_PID_FILE@;%s/mgetty.pid.$TTY;g'\\\n", VARRUNDIR);
 #ifdef SVR4
     printf( "      -e 's;@LOCK@;%s/LK.iii.jjj.kkk;g'\\\n", LOCK_PATH );
 #else
