@@ -1,4 +1,4 @@
-#ident "$Id: syslibs.h,v 4.1 1997/01/12 14:53:46 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: syslibs.h,v 4.2 2001/09/28 21:09:40 gert Exp $ Copyright (c) Gert Doering"
 
 /* Include stdlib.h / malloc.h, depending on the O/S
  */
@@ -7,7 +7,7 @@
 #include <stdlib.h>
 #endif
 
-#if !defined( __bsdi__ ) && !defined(__FreeBSD__) && !defined(NeXT)
+#if !defined( __bsdi__ ) && !defined(__FreeBSD__) && !defined(__OpenBSD__) && !defined(NeXT)
 #include <malloc.h>
 #endif
 
