@@ -1,4 +1,4 @@
-#ident "$Id: tio.c,v 4.3 1998/01/20 10:40:46 gert Exp $ Copyright (c) 1993 Gert Doering"
+#ident "$Id: tio.c,v 4.5 2000/10/22 10:45:20 gert Exp $ Copyright (c) 1993 Gert Doering"
 
 /* tio.c
  *
@@ -30,9 +30,6 @@ static char tio_compilation_type[]="@(#)tio.c compiled with BSD_SGTTY";
 #ifdef USE_TERMIOX
 # include <sys/termiox.h>
 #endif
-#ifdef _HPUX_SOURCE
-# include <sys/modem.h>
-#endif
 
 #if defined( M_UNIX ) && defined( MAM_BUG )
 #include <fcntl.h>
@@ -218,7 +215,8 @@ int tio_set_speed _P2( (t, speed ), TIO *t, unsigned int speed )
 
     for ( i=0; speedtab[i].cbaud != 0; i++ )
     {
-	if ( speedtab[i].nspeed == speed ) symspeed = speedtab[i].cbaud;
+	if ( speedtab[i].nspeed == speed ) 
+		{ symspeed = speedtab[i].cbaud; break; }
     }
 
     if ( symspeed == 0 )
