@@ -3,7 +3,7 @@
  *
  * Defines the structure with data and routines for the hardware drivers.
  *
- * $Id: hardware.h,v 1.11 1999/06/15 12:38:22 marcs Exp $
+ * $Id: hardware.h,v 1.18 2001/02/24 11:43:39 marcs Exp $
  *
  */
 
@@ -70,6 +70,7 @@ typedef struct
      int (*voice_mode_on) (void);
      int (*wait) (int timeout);
      int (*play_dtmf) (char* number);
+     int (*check_rmd_adequation) (char *rmd_name); /* not NUL terminated */
      vmq_t voice_modem_quirks;
      } voice_modem_struct;
 
@@ -93,15 +94,21 @@ extern voice_modem_struct Dolphin;
 extern voice_modem_struct Digi_RAS;
 extern voice_modem_struct Dr_Neuhaus;
 extern voice_modem_struct Elsa;
+extern voice_modem_struct V253modem;
 extern voice_modem_struct IS_101;
 extern voice_modem_struct ISDN4Linux;
 extern voice_modem_struct Supra;
+extern voice_modem_struct Supra56ePRO;
 extern voice_modem_struct Multitech_2834ZDXv;
 extern voice_modem_struct Multitech_5634ZBAV;
 extern voice_modem_struct Multitech_5600ZDXv;
+extern voice_modem_struct Multitech_5634ZPX;
 extern voice_modem_struct Rockwell;
 extern voice_modem_struct Sierra;
 extern voice_modem_struct UMC;
 extern voice_modem_struct US_Robotics;
 extern voice_modem_struct ZyXEL_1496;
 extern voice_modem_struct ZyXEL_2864;
+extern voice_modem_struct ZyXEL_Omni56K;
+extern voice_modem_struct Lucent;
+
