@@ -5,7 +5,7 @@
  * follow the IS-101 interim standard for voice modems. Since the commands
  * are set in the modem structure, it should be quite generic.
  *
- * $Id: IS_101.c,v 1.9 1999/07/20 07:41:09 marcs Exp $
+ * $Id: IS_101.c,v 1.14 2001/08/06 17:46:18 marcs Exp $
  *
  */
 
@@ -548,8 +548,10 @@ int IS_101_play_file(FILE *fd, int bps)
      int bytes_out;
      int bytes_max = bps / 8 / 10;
      int count = 0;
-     int count_limit = bps / 8 * cvd.watchdog_timeout.d.i / 2;
      int play_complete = FALSE;
+     time_t watchdog_reset;
+
+     watchdog_reset = time(NULL) + (cvd.watchdog_timeout.d.i / 2);
 
      if (bytes_max > PLAY_BUFFER_SIZE)
           bytes_max = PLAY_BUFFER_SIZE;
@@ -582,10 +584,11 @@ int IS_101_play_file(FILE *fd, int bps)
 
           count += bytes_out;
 
-          if (count > count_limit)
+          if (watchdog_reset < time(NULL))
                {
                lprintf(L_JUNK, "%s: <VOICE DATA %d bytes>", program_name, count);
                reset_watchdog();
+               watchdog_reset = time(NULL) + (cvd.watchdog_timeout.d.i / 2);
                count = 0;
                }
 
@@ -629,7 +632,9 @@ int IS_101_record_file(FILE *fd, int bps)
      int was_DLE = FALSE;
      int tcount = 0;
      int count = 0;
-     int count_limit = bps / 8 * cvd.watchdog_timeout.d.i / 2;
+     time_t watchdog_reset;
+
+     watchdog_reset = time(NULL) + (cvd.watchdog_timeout.d.i / 2);
 
      reset_watchdog();
      timeout = time(NULL) + cvd.rec_max_len.d.i;
@@ -688,6 +693,7 @@ int IS_101_record_file(FILE *fd, int bps)
                                voice_modem_name, count);
                               lprintf(L_JUNK, "%s: <DLE> <ETX>",
                                voice_modem_name);
+                              voice_modem->handle_dle(input_byte);
                               break;
                          case SUB:
                               fputc(DLE, fd);
@@ -723,11 +729,12 @@ int IS_101_record_file(FILE *fd, int bps)
 
                count++;
 
-               if (count > count_limit)
+               if (watchdog_reset < time(NULL))
                     {
                     lprintf(L_JUNK, "%s: <VOICE DATA %d bytes>", voice_modem_name,
                      count);
                     reset_watchdog();
+                    watchdog_reset = time(NULL) + (cvd.watchdog_timeout.d.i / 2);
                     count = 0;
                     }
 
@@ -862,6 +869,7 @@ int IS_101_wait(int wait_timeout)
      {
      time_t timeout;
      int watchdog_count = 0;
+     int in_dle = FALSE;
 
      reset_watchdog();
      stop_waiting = FALSE;
@@ -880,30 +888,35 @@ int IS_101_wait(int wait_timeout)
                 cvd.poll_interval.d.i / 2;
                }
 
-          while ((char_read = voice_read_byte()) >= 0)
-               {
-
-               if (char_read == DLE)
-                    {
-
-                    if ((char_read = voice_read_byte()) <= 0)
-                         return(FAIL);
-
-                    lprintf(L_JUNK, "%s: <DLE> <%c>", voice_modem_name,
-                     char_read);
-                    voice_modem->handle_dle(char_read);
-                    }
-               else
-                    lprintf(L_WARN,
-                     "%s: unexpected byte <%c> from voice modem",
-                     program_name, char_read);
-
-               };
+          while ((char_read = voice_read_byte()) >= 0) {
+             if (in_dle) {
+                lprintf(L_JUNK,
+                        "%s: <DLE> <%c>",
+                        voice_modem_name,
+                        char_read);
+                voice_modem->handle_dle(char_read);
+                in_dle = FALSE;
+             }
+             else if (char_read == DLE) {
+                in_dle = TRUE;
+             }
+             else {
+                  lprintf(L_WARN,
+                   "%s: unexpected byte <%c> from voice modem",
+                   program_name, char_read);
+             }
+	  };
 
           voice_check_events();
           delay(cvd.poll_interval.d.i);
           };
 
+     /* We didn't receive the accompanying byte */
+     if (in_dle) {
+        lprintf(L_FATAL, "%s: <DLE> not followed by anything", program_name);
+        return FAIL;
+     }
+
      voice_check_events();
      voice_modem_state = IDLE;
      return(OK);
@@ -933,6 +946,11 @@ int IS_101_play_dtmf(char* number)
      return(OK);
      }
 
+int IS_101_check_rmd_adequation(char *rmd_name) {
+   return !strncmp(rmd_name,
+                   voice_modem_rmd_name,
+                   strlen(voice_modem_rmd_name));
+}
 
 const char IS_101_pick_phone_cmnd[] = "AT+VLS=2";
 const char IS_101_pick_phone_answr[] = "OK";
@@ -1018,5 +1036,6 @@ voice_modem_struct IS_101 =
      &IS_101_voice_mode_on,
      &IS_101_wait,
      &IS_101_play_dtmf,
+     &IS_101_check_rmd_adequation,
      0
      };
