@@ -4,7 +4,7 @@
  * Executes the shell script given as the argument. If the argument is
  * empty, commands are read from standard input.
  *
- * $Id: shell.c,v 1.8 1999/07/20 07:41:08 marcs Exp $
+ * $Id: shell.c,v 1.16 2001/08/06 17:45:17 marcs Exp $
  *
  */
 
@@ -18,12 +18,16 @@ static int voice_shell_output_fd = NO_VOICE_FD;
 static int child_pid = 0;
 static int level = 0;
 static int autostop = FALSE;
+const char ErrorString[] = "ERROR";
+const char ReadyString[] = "READY" ;
+const char Device_not_avail_String[] = "DEVICE_NOT_AVAILABLE" ;
 
 int voice_execute_shell_script(char *shell_script, char **shell_options)
      {
      int arg_index = 0;
      int start_index;
      char **shell_arguments;
+     int should_close_2 = 0;
 
      if (strlen(shell_script) == 0)
           lprintf(L_MESG, "%s: Executing shell %s", program_name, shell_script, cvd.voice_shell.d.p);
@@ -31,6 +35,51 @@ int voice_execute_shell_script(char *shell_script, char **shell_options)
           lprintf(L_MESG, "%s: Executing shell script %s with shell %s", program_name, shell_script,
            cvd.voice_shell.d.p);
 
+     if (cvd.voice_shell_log.d.p && ((char *) cvd.voice_shell_log.d.p)[0])
+     {
+        char log_file_name[MAXPATH];
+
+	if ( strlen( cvd.voice_shell_log.d.p ) + strlen( DevID ) + 5 > 
+	       sizeof( log_file_name ) )
+	{
+	    lprintf( L_WARN, "%s: path name for shell log too long - ignoring",
+			program_name );
+	}
+        else {
+           int shell_stderr_fd;
+
+	   sprintf( log_file_name, cvd.voice_shell_log.d.p, DevID );
+
+           shell_stderr_fd = open(log_file_name,
+                                      O_WRONLY | O_CREAT | O_APPEND);
+
+	   /* FIXME: this really should go after the fork() call, as
+	    * it will destroy vgetty's fd = 2, which might be needed
+	    * later on (if the call switches to data, and we hand over
+	    * to /bin/login and /bin/sh later) - gert.
+	    */
+           if (shell_stderr_fd != -1) {
+	      /* This means we are going to close the old fd 2 if any */
+	      if (dup2(shell_stderr_fd, 2) == -1)
+	      {
+		 lprintf(L_ERROR, "%s: couldn't dup2() shell log file",
+			 program_name);
+	      }
+	      else {
+		 should_close_2 = 1;
+	      }
+
+	      close(shell_stderr_fd);
+           }
+           else {
+              lprintf(L_ERROR,
+                      "%s: couldn't open() shell log file %s",
+                      program_name,
+                      log_file_name);
+           }
+        }
+     }
+
      if (getenv("VOICE_PID") == NULL)
           {
           int parent_pid = getpid();
@@ -96,6 +145,10 @@ int voice_execute_shell_script(char *shell_script, char **shell_options)
                     close(pipe_in[0]);
                     close(pipe_out[1]);
 
+                    if (should_close_2) {
+                       close(2); /* from the dup2 */
+                    }
+
                     if (voice_write_shell("HELLO SHELL") != OK)
                          return(FAIL);
 
@@ -225,7 +278,7 @@ int voice_shell_handle_event(int event, event_data data)
                     return(FAIL);
                     };
 
-               if (voice_write_shell("READY") != OK)
+               if (voice_write_shell(ReadyString) != OK)
                     return(FAIL);
 
                voice_shell_state = ON_LINE;
@@ -249,13 +302,13 @@ int voice_shell_handle_event(int event, event_data data)
                          case IDLE:
                               lprintf(L_NOISE, "%s: STOP during IDLE", program_name);
 
-                              if (voice_write_shell("READY") != OK)
+                              if (voice_write_shell(ReadyString) != OK)
                                    return(FAIL);
 
                               break;
                          default:
 
-                              if (voice_write_shell("ERROR") != OK)
+                              if (voice_write_shell(ErrorString) != OK)
                                    return(FAIL);
 
                          };
@@ -265,7 +318,7 @@ int voice_shell_handle_event(int event, event_data data)
                     {
                     lprintf(L_MESG, "%s: Nested command in shell script", program_name);
 
-                    if (voice_write_shell("ERROR") != OK)
+                    if (voice_write_shell(ErrorString) != OK)
                          return(FAIL);
 
                     }
@@ -281,37 +334,82 @@ int voice_shell_handle_event(int event, event_data data)
 
                     if (voice_beep(frequency, length) != OK)
 
-                         if (voice_write_shell("ERROR") != OK)
+                         if (voice_write_shell(ErrorString) != OK)
                               return(FAIL);
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
+               else if (strncmp(buffer, "QUOTE", 5) == 0)
+                    {
+                    char quoted_cmd[VOICE_BUF_LEN] = "";
+                    
+                    sscanf(buffer, "%*s %s", quoted_cmd);
+
+                    lprintf(L_MESG, "%s: SENDING QUOTED CMD \"%s\"",
+                            program_name, quoted_cmd);
+                       
+                    if (voice_command(quoted_cmd, "OK") == VMA_FAIL)
+                        {
+                         if (voice_write_shell(ErrorString) != OK)
+                              return(FAIL);
+                        }
+                      
+                    if (voice_write_shell(ReadyString) != OK)
+                       return(FAIL);
+                    }
                else if (strncmp(buffer, "DEVICE", 6) == 0)
                     {
                     char device[VOICE_BUF_LEN] = "";
+                    int ResultCode = FAIL;
 
                     sscanf(buffer, "%*s %s", device);
 
                     if (strcmp(device, "NO_DEVICE") == 0)
-                         voice_set_device(NO_DEVICE);
+		      ResultCode = voice_set_device(NO_DEVICE);
                     else if (strcmp(device, "DIALUP_LINE") == 0)
-                         voice_set_device(DIALUP_LINE);
+		      ResultCode = voice_set_device(DIALUP_LINE);
+		    else if (strcmp(device, "INTERNAL_MICROPHONE") == 0)
+		      ResultCode = voice_set_device(INTERNAL_MICROPHONE);
                     else if (strcmp(device, "EXTERNAL_MICROPHONE") == 0)
-                         voice_set_device(EXTERNAL_MICROPHONE);
+		      ResultCode = voice_set_device(EXTERNAL_MICROPHONE);
                     else if (strcmp(device, "INTERNAL_SPEAKER") == 0)
-                         voice_set_device(INTERNAL_SPEAKER);
+		      ResultCode = voice_set_device(INTERNAL_SPEAKER);
                     else if (strcmp(device, "EXTERNAL_SPEAKER") == 0)
-                         voice_set_device(EXTERNAL_SPEAKER);
+		      ResultCode = voice_set_device(EXTERNAL_SPEAKER);
                     else if (strcmp(device, "LOCAL_HANDSET") == 0)
-                         voice_set_device(LOCAL_HANDSET);
-                    else if (voice_write_shell("ERROR") != OK)
-                         return(FAIL);
-
-                    if (voice_write_shell("READY") != OK)
-                         return(FAIL);
+		      ResultCode = voice_set_device(LOCAL_HANDSET);
+		    else if (strcmp(device, "DIALUP_WITH_EXT_SPEAKER") == 0)
+		      ResultCode = voice_set_device(DIALUP_WITH_EXT_SPEAKER);
+		    else if (strcmp(device, "DIALUP_WITH_INT_SPEAKER") == 0)
+		      ResultCode = voice_set_device(DIALUP_WITH_INT_SPEAKER);
+		    else if (strcmp(device, "DIALUP_WITH_LOCAL_HANDSET") == 0)
+		      ResultCode = voice_set_device(DIALUP_WITH_LOCAL_HANDSET);
+		    else if (strcmp(device, "DIALUP_WITH_EXTERNAL_MIC_AND_SPEAKER") == 0)
+		      ResultCode
+                      = voice_set_device(DIALUP_WITH_EXTERNAL_MIC_AND_SPEAKER);
+		    else if (strcmp(device, "DIALUP_WITH_INTERNAL_MIC_AND_SPEAKER") == 0)
+		      ResultCode
+                      = voice_set_device(DIALUP_WITH_INTERNAL_MIC_AND_SPEAKER);
+                    else if (voice_write_shell(ErrorString) != OK)
+		      return(FAIL);
 
+		    switch(ResultCode)
+		      {
+		      case OK:
+			if (voice_write_shell(ReadyString) != OK)
+			  return(FAIL);
+                        break;
+		      case VMA_DEVICE_NOT_AVAIL:
+			if (voice_write_shell(Device_not_avail_String) != OK)
+			  return(FAIL);
+                        break;
+		      default: /* FAIL and unknown return values */
+			if (voice_write_shell(ErrorString) != OK)
+			  return(FAIL);
+                        break;
+		      } /* switch(ResultCode) */
                     }
                else if (strncmp(buffer, "DIAL", 4) == 0)
                     {
@@ -324,10 +422,10 @@ int voice_shell_handle_event(int event, event_data data)
 
                     if (voice_dial((void *) phone_number) == FAIL)
 
-                         if (voice_write_shell("ERROR") != OK)
+                         if (voice_write_shell(ErrorString) != OK)
                               return(FAIL);
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -335,7 +433,7 @@ int voice_shell_handle_event(int event, event_data data)
                     {
                     events_to_shell = FALSE;
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -343,7 +441,7 @@ int voice_shell_handle_event(int event, event_data data)
                     {
                     events_to_shell = TRUE;
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -353,7 +451,7 @@ int voice_shell_handle_event(int event, event_data data)
                     if (voice_write_shell(DevID) != OK)
                          return(FAIL);
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -364,7 +462,7 @@ int voice_shell_handle_event(int event, event_data data)
                     if (voice_write_shell(voice_modem_name) != OK)
                          return(FAIL);
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -372,7 +470,7 @@ int voice_shell_handle_event(int event, event_data data)
                     {
                     autostop = TRUE;
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -380,7 +478,7 @@ int voice_shell_handle_event(int event, event_data data)
                     {
                     autostop = FALSE;
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -398,7 +496,7 @@ int voice_shell_handle_event(int event, event_data data)
 /*
                     if (voice_device != DIALUP_LINE)
 
-                         if (voice_write_shell("ERROR") != OK)
+                         if (voice_write_shell(ErrorString) != OK)
                               return(FAIL);
 */
 
@@ -407,7 +505,15 @@ int voice_shell_handle_event(int event, event_data data)
                     if (voice_write_shell("RECEIVING") != OK)
                          return(FAIL);
 
-                    enter_fax_mode();
+		    if (enter_data_fax_mode(ANSWER_FAX)
+			== FAIL) {
+		       lprintf(L_WARN, "%s: Could not switch to fax mode",
+		               program_name);
+                       /* otherwise result ignored, which is already much
+                        * better than before.
+                        */
+		    }
+
                     voice_write("ATA"); /* faxrec will eat the rest */
                     voice_faxrec(path, 0);
                     voice_init();
@@ -415,7 +521,7 @@ int voice_shell_handle_event(int event, event_data data)
                     voice_set_device(DIALUP_LINE);
                     voice_shell_notify();
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -431,7 +537,14 @@ int voice_shell_handle_event(int event, event_data data)
 
                     if (av[0] != NULL)
                          {
-                         enter_fax_mode();
+			 if (enter_data_fax_mode(ANSWER_FAX)
+			     == FAIL) {
+			    lprintf(L_WARN, "%s: Could not switch to fax mode",
+				    program_name);
+			    /* otherwise result ignored, which is already much
+			     * better than before.
+			     */
+			 }
                          voice_faxsnd(av, 0, 3);
                          voice_init();
                          voice_mode_on();
@@ -441,12 +554,12 @@ int voice_shell_handle_event(int event, event_data data)
                     else
                          {
 
-                         if (voice_write_shell("ERROR") != OK)
+                         if (voice_write_shell(ErrorString) != OK)
                               return(FAIL);
 
                          }
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -465,21 +578,21 @@ int voice_shell_handle_event(int event, event_data data)
 
                          if (voice_play_file(name) == FAIL)
 
-                              if (voice_write_shell("ERROR") != OK)
+                              if (voice_write_shell(ErrorString) != OK)
                                    return(FAIL);
 
                          }
                     else
                          {
 
-                         if (voice_write_shell("ERROR") != OK)
+                         if (voice_write_shell(ErrorString) != OK)
                               return(FAIL);
 
                          }
 
                     voice_shell_linger = 0;
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -497,19 +610,19 @@ int voice_shell_handle_event(int event, event_data data)
 
                          if (voice_record_file(name) != OK)
 
-                              if (voice_write_shell("ERROR") != OK)
+                              if (voice_write_shell(ErrorString) != OK)
                                    return(FAIL);
 
                          }
                     else
                          {
 
-                         if (voice_write_shell("ERROR") != OK)
+                         if (voice_write_shell(ErrorString) != OK)
                               return(FAIL);
 
                          }
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -524,10 +637,10 @@ int voice_shell_handle_event(int event, event_data data)
 
                     if (voice_wait(length) != OK)
 
-                         if (voice_write_shell("ERROR") != OK)
+                         if (voice_write_shell(ErrorString) != OK)
                               return(FAIL);
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     }
@@ -542,17 +655,17 @@ int voice_shell_handle_event(int event, event_data data)
 
                     if (voice_play_dtmf(number) == FAIL)
 
-                         if (voice_write_shell("ERROR") != OK)
+                         if (voice_write_shell(ErrorString) != OK)
                               return(FAIL);
 
-                    if (voice_write_shell("READY") != OK)
+                    if (voice_write_shell(ReadyString) != OK)
                          return(FAIL);
 
                     } 
                else
                     {
 
-                    if (voice_write_shell("ERROR") != OK)
+                    if (voice_write_shell(ErrorString) != OK)
                          return(FAIL);
 
                     }
@@ -658,6 +771,13 @@ int voice_shell_handle_event(int event, event_data data)
                          return(FAIL);
 
                     return(OK);
+               case NO_CARRIER:
+ 
+                    if (voice_write_shell("NO_CARRIER") != OK)
+                         return(FAIL);
+                 
+                    return(OK);
+
                case NO_DIAL_TONE:
 
                     if (voice_write_shell("NO_DIAL_TONE") != OK)
