@@ -1,7 +1,7 @@
 /*
  * answer.c
  *
- * $Id: answer.c,v 1.12 1999/06/27 14:29:03 marcs Exp $
+ * $Id: answer.c,v 1.20 2001/03/11 12:40:11 marcs Exp $
  *
  */
 
@@ -14,96 +14,16 @@ int first_dtmf;
 int hangup_requested;
 int switch_to_data_fax_mode;
 
-static int enter_data_fax_mode(int answer_mode)
-     {
-     int bit_order = 0;
-     char *fax_mode = NULL;
+/* This wrapper is used for answering functions at the vgetty
+ * call initialization.
+ */
+static int enter_data_fax_mode_wrapper(int answer_mode) {
+   if (cvd.force_autodetect.d.i) {
+      answer_mode = ANSWER_DATA | ANSWER_FAX;
+   }
 
-     answer_mode &= (ANSWER_DATA | ANSWER_FAX);
-
-     if (answer_mode == 0)
-          {
-          lprintf(L_NOISE,
-           "%s: answer mode is set to not accept data or fax connections",
-           program_name);
-          exit(99);
-          };
-
-     if (cvd.force_autodetect.d.i)
-          answer_mode = ANSWER_DATA | ANSWER_FAX;
-
-     if (modem_type == Mt_class2)
-          {
-          bit_order = 0;
-	  /* following the specs, we should go to +FCLASS=2;+FAA=1, but
-	   * there is a fair number of Rockwell modems that can't do
-	   * data calls if in that mode - must go to +FCLASS=0;+FAA=1 -
-	   * but yet other modems NEED class 2, so use modem_quirks...
-	   */
-          fax_mode = ( modem_quirks & MQ_NEED2 ) ? "2": "0";
-          };
-
-     if (modem_type == Mt_class2_0)
-          {
-          bit_order = 1;
-          fax_mode = "2.0";
-          };
-
-     if ((modem_type == Mt_data) || (fax_mode == NULL))
-          answer_mode &= ANSWER_DATA;
-
-     if (answer_mode == 0)
-          {
-          lprintf(L_NOISE, "%s: modem does not support wanted answer mode",
-           program_name);
-          return(FAIL);
-          };
-
-     switch (answer_mode)
-          {
-          case ANSWER_DATA | ANSWER_FAX:
-               lprintf(L_JUNK, "%s: trying data and fax connection",
-                program_name);
-
-               if (voice_switch_to_data_fax(fax_mode) == FAIL)
-                    return(FAIL);
-
-               if (voice_command("AT+FAA=1", "OK") != VMA_USER_1)
-                    return(FAIL);
-
-               tio_set(voice_fd, &tio_save);
-               voice_restore_signal_handler();
-               fax_set_bor(voice_fd, bit_order);
-               break;
-          case ANSWER_DATA:
-               lprintf(L_JUNK, "%s: trying data connection", program_name);
-
-               if (voice_switch_to_data_fax("0") == FAIL)
-                    return(FAIL);
-
-               if (voice_command("AT+FAA=0", "OK") != VMA_USER_1)
-                    return(FAIL);
-
-               tio_set(voice_fd, &tio_save);
-               voice_restore_signal_handler();
-               break;
-          case ANSWER_FAX:
-               lprintf(L_JUNK, "%s: trying fax connection", program_name);
-
-               if (voice_switch_to_data_fax(fax_mode) == FAIL)
-                    return(FAIL);
-
-               if (voice_command("AT+FAA=0", "OK") != VMA_USER_1)
-                    return(FAIL);
-
-               tio_set(voice_fd, &tio_save);
-               voice_restore_signal_handler();
-               fax_set_bor(voice_fd, bit_order);
-               break;
-          };
-
-     return(OK);
-     }
+   return enter_data_fax_mode(answer_mode);
+}
 
 static int get_answer_mode(char* ring_type)
      {
@@ -287,9 +207,12 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
      char greeting_message[VOICE_BUF_LEN];
      char receive_dir[VOICE_BUF_LEN];
      char message[VOICE_BUF_LEN];
-     char message_name[VOICE_BUF_LEN] = "vXXXXXX";
+     char message_name[VOICE_BUF_LEN];
      char *ring_type = "ring";
+     int i, j;
      int result;
+     char c;
+     pid_t pid = getpid();
 
      setup_environment(); /* caller ID, called ID and stuff */
 
@@ -329,7 +252,8 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
      if ((answer_mode & ANSWER_VOICE) == 0)
           {
 
-          if (enter_data_fax_mode(answer_mode) == FAIL)
+          if (enter_data_fax_mode_wrapper(answer_mode)
+              == FAIL)
                {
                lprintf(L_WARN, "%s: Could not switch to data or fax mode",
                 program_name);
@@ -340,10 +264,6 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
           };
 
      get_greeting_message(greeting_message);
-     make_path(receive_dir, cvd.voice_dir.d.p, cvd.receive_dir.d.p);
-     mktemp(message_name);
-     strcat(message_name, ".rmd");
-     make_path(message, receive_dir, message_name);
      strcpy(dtmf_code, "");
      execute_dtmf_script = FALSE;
      first_dtmf = TRUE;
@@ -358,35 +278,88 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
           }
 
      if (voice_modem_quirks() & VMQ_NEEDS_SET_DEVICE_BEFORE_ANSWER) {
-       if (voice_set_device(DIALUP_LINE) == FAIL) {
+       if (voice_set_device(DIALUP_LINE) != OK) {
 	 lprintf(L_WARN, "%s: Could not switch to dialup line",
 		 program_name);
 	 exit(99);
        }
      }
 
-     if ((result = voice_answer_phone()) == VMA_CONNECT)
-          {
-          voice_restore_signal_handler();
-          tio_set(voice_fd, &tio_save);
-          return(VMA_CONNECT);
-          }
+     result = voice_answer_phone();
+     switch (result) {
+        case VMA_OK:
+           /* VOICE */
+           break;
+        case VMA_CONNECT:
+           /* DATA */
+        case VMA_FCON:
+           /* FAX */
+        case VMA_FAX:
+        case VMA_FCO:
+           voice_restore_signal_handler();
+           tio_set(voice_fd, &tio_save);
+           return result;
+           break;
+        default:
+           lprintf(L_WARN, "%s: Could not answer the phone. Strange...",
+                           program_name);
+           exit(99);
+           break;
+     }
+
+     make_path(receive_dir, cvd.voice_dir.d.p, cvd.receive_dir.d.p);
+
+     /* The file name is made from "v", then the pid, then the
+      * time_t, then the possible CallerId, plus separators.
+      * The caller-ID is truncated at 16 characters.
+      * NOTES
+      *    - On system not supporting standard file names (e.g. 14-characters
+      *      sysvfs), only the pid will be used.
+      */
+
+#ifdef SHORT_FILENAMES
+     sprintf(message_name, "v%u",
+             pid);
+#else /* !SHORT_FILENAMES */
+     sprintf(message_name, "v-%u-%u",
+             pid,
+             (unsigned int) time(NULL));
+#endif /* !SHORT_FILENAMES */
+
+#ifndef SHORT_FILENAMES
+     /* Include caller ID string in the file name */
+     if (strcmp(CallerId, "none")) {
+         i = strlen(message_name);
+         message_name[i++] = '-';
+         for (j = 0; j < 16 && CallerId[j]; j++) {
+             c = CallerId[j];
+             if (c == ' ' || c == '/' || c == '\\'|| c == '&' || c == ';' ||
+                 c == '(' || c == ')' || c == '>' || c == '<' || c == '|' ||
+                 c == '?' || c == '*' || c == '\''|| c == '"' || c == '`')
+                 {
+                 if (message_name[i-1] != '-')
+                     message_name[i++] = '-' ;
+                 }
+             else
+                 message_name[i++] = c;
+         }
+         if (message_name[i-1] == '-')
+             i--;
+         message_name[i] = '\0';
+     }
+#endif
+
+     strcat(message_name, ".rmd");
+     make_path(message, receive_dir, message_name);
 
      if (!(voice_modem_quirks() & VMQ_NEEDS_SET_DEVICE_BEFORE_ANSWER)) {
-       if (voice_set_device(DIALUP_LINE) == FAIL) {
+       if (voice_set_device(DIALUP_LINE) != OK) {
 	   lprintf(L_WARN, "%s: Could not switch to dialup line",
 		   program_name);
 	   exit(99);
 	 }
      }
 
-     if (result == VMA_ERROR)
-          {
-          lprintf(L_WARN, "%s: Could not answer the phone. Strange...",
-           program_name);
-          exit(99);
-          }
-
      if (strlen(cvd.call_program.d.p) != 0)
           {
           char *arguments[2];
@@ -400,7 +373,8 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
 
           if (result == FAIL)
                {
-               lprintf(L_WARN, "%s: shell script %s exited unnormally");
+               lprintf(L_WARN, "%s: shell script %s exited unnormally",
+                       program_name, call_program);
                }
           else
 
@@ -408,8 +382,9 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
                     {
                     case 1:
 
-                         if (enter_data_fax_mode(answer_mode & ANSWER_DATA) ==
-                          FAIL)
+                         if (enter_data_fax_mode_wrapper
+                                (answer_mode & ANSWER_DATA)
+                             == FAIL)
                               {
                               lprintf(L_WARN,
                                "%s: Could not switch to data mode",
@@ -420,7 +395,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
                          return(VMA_OK);
                     case 2:
 
-                         if (enter_data_fax_mode(answer_mode & ANSWER_FAX) ==
+                         if (enter_data_fax_mode_wrapper(answer_mode & ANSWER_FAX) ==
                           FAIL)
                               {
                               lprintf(L_WARN,
@@ -432,7 +407,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
                          return(VMA_OK);
                     case 3:
 
-                         if (enter_data_fax_mode(answer_mode & (ANSWER_DATA |
+                         if (enter_data_fax_mode_wrapper(answer_mode & (ANSWER_DATA |
                           ANSWER_FAX)) == FAIL)
                               {
                               lprintf(L_WARN,
@@ -444,7 +419,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
                          return(VMA_OK);
                     default:
 
-                         if (voice_set_device(NO_DEVICE) == FAIL)
+                         if (voice_set_device(NO_DEVICE) != OK)
                               {
                               lprintf(L_WARN,
                                "%s: Could not hang up the line",
@@ -493,13 +468,15 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
            CallName, CallerId, DevID, getpid());
           voice_execute_shell_script(dtmf_program, arguments);
 
-          if (voice_set_device(NO_DEVICE) == FAIL)
+#if 0
+/* selecting NO_DEVICE means to hang up the line-> so vgetty shouldn't do this! */
+          if (voice_set_device(NO_DEVICE) != OK)
                {
                lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
                exit(99);
                }
-
+#endif
           if (voice_mode_off() == FAIL)
                {
                lprintf(L_WARN, "%s: Could not turn off voice mode",
@@ -523,7 +500,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
            "hangup requested, name='%s', caller=%s, dev=%s, pid=%d",
            CallName, CallerId, DevID, getpid());
 
-          if (voice_set_device(NO_DEVICE) == FAIL)
+          if (voice_set_device(NO_DEVICE) != OK)
                {
                lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
@@ -550,7 +527,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
      if (switch_to_data_fax_mode)
           {
 
-          if (enter_data_fax_mode(answer_mode) == FAIL)
+          if (enter_data_fax_mode_wrapper(answer_mode) == FAIL)
                {
                lprintf(L_WARN, "%s: Could not switch to data/fax mode",
                 program_name);
@@ -579,13 +556,15 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
            CallName, CallerId, DevID, getpid());
           voice_execute_shell_script(dtmf_program, arguments);
 
+#if 0
+/* the dtmf program can't do anything with a disconnected line */
           if (voice_set_device(NO_DEVICE) == FAIL)
                {
                lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
                exit(99);
                }
-
+#endif
           if (voice_mode_off() == FAIL)
                {
                lprintf(L_WARN, "%s: Could not turn off voice mode",
@@ -609,7 +588,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
            "hangup requested, name='%s', caller=%s, dev=%s, pid=%d",
            CallName, CallerId, DevID, getpid());
 
-          if (voice_set_device(NO_DEVICE) == FAIL)
+          if (voice_set_device(NO_DEVICE) != OK)
                {
                lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
@@ -636,7 +615,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
      if (switch_to_data_fax_mode)
           {
 
-          if (enter_data_fax_mode(answer_mode) == FAIL)
+          if (enter_data_fax_mode_wrapper(answer_mode) == FAIL)
                {
                lprintf(L_WARN, "%s: Could not switch to data/fax mode",
                 program_name);
@@ -684,12 +663,14 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
            CallName, CallerId, DevID, getpid());
           voice_execute_shell_script(dtmf_program, arguments);
 
+#if 0
           if (voice_set_device(NO_DEVICE) == FAIL)
                {
                lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
                exit(99);
                }
+#endif
 
           if (voice_mode_off() == FAIL)
                {
@@ -712,7 +693,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
           {
           remove_message(message);
 
-          if (enter_data_fax_mode(answer_mode) == FAIL)
+          if (enter_data_fax_mode_wrapper(answer_mode) == FAIL)
                {
                lprintf(L_WARN, "%s: Could not switch to data/fax mode",
                 program_name);
@@ -727,7 +708,7 @@ int vgetty_answer(int rings, int rings_wanted, int dist_ring)
           if (voice_beep(cvd.beep_frequency.d.i, cvd.beep_length.d.i) == FAIL)
                lprintf(L_WARN, "%s: Beep command failed");
 
-     if (voice_set_device(NO_DEVICE) == FAIL)
+     if (voice_set_device(NO_DEVICE) != OK)
           {
           lprintf(L_WARN, "%s: Could not hang up the line",
            program_name);
